@@ -13,6 +13,10 @@ SUPPLEMENTAL = 'supp'
 WORD_FREQ = 'freq'
 LINKS = 'link'
 
+# fieldnames we trust can be populated using linked content in dictionaries
+# pronunciation-related data should not go here; links typically represent meaning only
+LINK_FRIENDLY_FIELDS = [PART_OF_SPEECH, DEFINITIONS, SYNONYMS, ANTONYMS]
+
 # Japanese specific
 PITCH_ACCENT = 'acnt'
 READING = 'read'
